@@ -147,9 +147,15 @@ class _NotificationBubble(Notify.Notification):
         if timeout != -1:
             self.set_timeout(timeout)
         if status_icon:
-            _, screen, area, orientation = status_icon.get_geometry()
-            self.set_hint_int32("x", area.x + area.width / 2)
-            self.set_hint_int32("y", area.y + area.height / 2)
+            ignored, screen, area, orientation = status_icon.get_geometry()
+            screen_width = screen.get_width()
+            screen_height = screen.get_height()
+            # Workaround a problem where we get garbage x and y values
+            if (area.x > 0 and area.y > 0) and (area.x <= screen_width and area.y <= screen_height):
+                self.set_hint_int32("x", area.x + area.width / 2)
+                self.set_hint_int32("y", area.y + area.height / 2)
+            else:
+                dprint("Got bad x %s or y %s value" % (area.x, area.y))
 
         self.show()
 
@@ -161,10 +167,18 @@ class Notification(object):
     def actions_supported():
         return "actions" in Notify.get_server_caps()
 
+    @staticmethod
+    def body_supported():
+        return "body" in Notify.get_server_caps()
+
     def __new__(cls, summary, message, timeout=-1, actions=None, actions_cb=None, pixbuf=None, status_icon=None):
-        if not Config('org.blueman.general')['notification-daemon'] or (actions and not cls.actions_supported()):
-            # Use fallback as user does not want to use a notification daemon or we have to show actions and the
-            # notification daemon does not provide them
+        forced_fallback = not Config('org.blueman.general')['notification-daemon']
+
+        if forced_fallback or not cls.body_supported() or (actions and not cls.actions_supported()):
+            # Use fallback in the case:
+            # * user does not want to use a notification daemon
+            # * the notification daemon is not available
+            # * we have to show actions and the notification daemon does not provide them
             klass = _NotificationDialog
         else:
             klass = _NotificationBubble
